import type React from "react";
import { HeroSection } from "@fchh/fcos-suite-ui";

interface Props {
  titleImage: string;
  children?: React.ReactNode;
}

const ContentWrapper: React.FC<Props> = ({ titleImage, children }) => {
  const TEXT_STYLE_MAPPING: Record<string, string> = {
    main: "font-plex fc-text-grey-900 prose",
    headings: "prose-headings:font-karla",
    subheading: "prose-h2:text-3xl",
    bullets: "prose-li:marker:text-grey-900",
    code: "prose-code:before:content-none prose-code:after:content-none",
    blockquote:
      "prose-blockquote:fc-border-l-2 sm:prose-blockquote:fc-border-l-4 prose-blockquote:fc-border-grey-900 prose-blockquote:fc-text-sm sm:prose-blockquote:fc-text-base prose-blockquote:fc-not-italic prose-blockquote:fc-leading-5 sm:prose-blockquote:fc-leading-6 prose-blockquote:fc-font-semibold prose-blockquote:fc-tracking-wider prose-blockquote:fc-uppercase",
    image: "prose-img:fc-w-full prose-img:fc-h-auto",
    video: "prose-video:fc-w-full prose-video:fc-h-auto",
  };

  return (
    <div className="fc-w-full fc-mb-10 xl:fc-mb-0">
      <HeroSection src={titleImage} />
      <section>
        <div className="container fc-flex fc-justify-between">
          <div className="fc-w-full xl:fc-w-[64%]">
            <div className="fc-mt-10 fc-mb-20 xl:fc-mb-44">
              <article
                className={`max-w-full ${TEXT_STYLE_MAPPING["main"]} ${TEXT_STYLE_MAPPING["headings"]} ${TEXT_STYLE_MAPPING["subheading"]} ${TEXT_STYLE_MAPPING["bullets"]} ${TEXT_STYLE_MAPPING["blockquote"]} ${TEXT_STYLE_MAPPING["image"]} ${TEXT_STYLE_MAPPING["video"]} ${TEXT_STYLE_MAPPING["code"]}`}
              >
                {children}
              </article>
            </div>
          </div>
          <div className="fc-hidden xl:fc-block fc-w-[18%]"></div>
        </div>
      </section>
    </div>
  );
};

export default ContentWrapper;
